@@ -34,9 +34,9 @@ public:
 
     void start() override
     {
-        QJsonArray urlsJson = data().value(QStringLiteral("urls")).toArray();
-        QString title = data().value(QStringLiteral("title")).toString();
-        QString message = i18n("%1 - %2").arg(title).arg(arrayToList(urlsJson).join(QLatin1Char(' ')));
+        QJsonArray urlsJson = data().value(QLatin1String("urls")).toArray();
+        QString title = data().value(QLatin1String("title")).toString();
+        QString message = i18n("%1 – %2").arg(title).arg(arrayToList(urlsJson).join(QLatin1Char(' ')));
 
         auto *job = new KIO::CommandLauncherJob(QStringLiteral("kdeconnect-sms"), {QStringLiteral("--message"), message});
         job->setDesktopName(QStringLiteral("org.kde.kdeconnect.sms"));
@@ -45,15 +45,11 @@ public:
     }
 };
 
-class Q_DECL_EXPORT KDEConnectSMSPlugin : public Purpose::PluginBase
+class KDEConnectSMSPlugin : public Purpose::PluginBase
 {
     Q_OBJECT
 public:
-    KDEConnectSMSPlugin(QObject *p, const QVariantList &)
-        : Purpose::PluginBase(p)
-    {
-    }
-
+    using PluginBase::PluginBase;
     Purpose::Job *createJob() const override
     {
         return new KDEConnectSMSJob(nullptr);
